@@ -1,7 +1,7 @@
 use nextcloud_config_parser::parse;
 
 fn main() {
-    let config = match parse("tests/configs/basic.php") {
+    let config = match parse("tests/configs/basic.php", false) {
         Ok(config) => config,
         Err(err) => {
             eprintln!("{}", err);
