@@ -82,8 +82,12 @@ fn merge_configs(input: Vec<(PathBuf, Value)>) -> Result<Value> {
     Ok(Value::Array(merged))
 }
 
-pub fn parse(path: impl AsRef<Path>) -> Result<Config> {
-    let files = glob_config_files(path);
+pub fn parse(path: impl AsRef<Path>, glob_files: bool) -> Result<Config> {
+    let files = if glob_files {
+        glob_config_files(path)
+    } else {
+        vec![path.as_ref().into()]
+    };
     let parsed_files = files
         .into_iter()
         .map(|path| {
@@ -342,7 +346,7 @@ use std::fmt::Debug;
 
 #[cfg(test)]
 fn config_from_file(path: &str) -> Config {
-    parse(path).unwrap()
+    parse(path, false).unwrap()
 }
 
 #[test]
@@ -546,7 +550,7 @@ fn test_parse_redis_cluster() {
 
 #[test]
 fn test_parse_config_multiple() {
-    let config = config_from_file("tests/configs/multiple/config.php");
+    let config = parse("tests/configs/multiple/config.php", true).unwrap();
     assert_eq!("https://cloud.example.com", config.nextcloud_url);
     assert_eq!("oc_", config.database_prefix);
     assert_debug_equal(
